Module multiplex

Module multiplex 

Structs

GetMultiplexProvider
Returns the list of providers configured for multiplex dispatch
SetMultiplexProvider
Sets the list of providers used when multiplexing prompts