Module multiplex
embacle_
mcp
0.15.13
Module multiplex
Module Items
Structs
In embacle_
mcp::
tools
embacle_mcp
::
tools
Module
multiplex
Structs

GetMultiplex
Provider
Returns the list of providers configured for multiplex dispatch
SetMultiplex
Provider
Sets the list of providers used when multiplexing prompts